﻿namespace Prism.Sample.Shell
{
    using System;
    using System.ComponentModel.Composition.Hosting;
    using System.Windows;
    using Microsoft.Practices.Prism.MefExtensions;
    using Microsoft.Practices.Prism.Modularity;

    /// <summary>
    /// Bootstraps the application using MEF.
    /// </summary>
    public class ApplicationBootstrapper : MefBootstrapper
    {
        /// <summary>
        /// Configures the <see cref="P:Microsoft.Practices.Prism.MefExtensions.MefBootstrapper.AggregateCatalog"/> used by MEF.
        /// </summary>
        protected override void ConfigureAggregateCatalog()
        {
            base.ConfigureAggregateCatalog();

            // Adds the SLModule.
            this.AggregateCatalog.Catalogs.Add(new AssemblyCatalog(typeof(Prism.Sample.FixedModule.Module).Assembly));
        }

        /// <summary>
        /// Creates the module catalog.
        /// </summary>
        /// <returns>The module catalog.</returns>
        protected override IModuleCatalog CreateModuleCatalog()
        {
            ModuleCatalog catalog = Microsoft.Practices.Prism.Modularity.ModuleCatalog.CreateFromXaml(new Uri("Prism.Sample.Shell;component/Modules/ModuleCatalog.xaml", UriKind.Relative));
            return catalog;
        }

        /// <summary>
        /// Creates the shell.
        /// </summary>
        /// <returns>The shell.</returns>
        protected override DependencyObject CreateShell()
        {
            return new Views.ShellView();
        }

        /// <summary>
        /// Initializes the shell.
        /// </summary>
        protected override void InitializeShell()
        {
            base.InitializeShell();
            Application.Current.RootVisual = this.Shell as UIElement;
        }
    }
}
